@@ -47,9 +47,9 @@ class CGSmartImage extends CGExtensions
   function LazyLoadFrontend() { return FALSE; }
   function GetName() { return get_class($this); }
   function GetFriendlyName() { return $this->Lang('friendlyname');  }
-  function GetVersion() { return '1.11'; }
+  function GetVersion() { return '1.12'; }
   function MinimumCMSVersion() { return '1.11.7'; }
-  function GetDependencies() { return array('CGExtensions'=>'1.36.2');   }
+  function GetDependencies() { return array('CGExtensions'=>'1.37.2');   }
   function GetAuthor() { return 'calguy1000'; }
   function GetAuthorEmail() { return 'calguy1000@gmail.com'; }
   function IsPluginModule() { return true; }
@@ -153,6 +153,8 @@ class CGSmartImage extends CGExtensions
     $this->CreateParameter('filter_rotate','',$this->Lang('param_filter_rotate'));
     $this->CreateParameter('filter_roundedcorners','',$this->Lang('param_filter_roundedcorners'));
     $this->CreateParameter('filter_sharpen','',$this->Lang('param_filter_sharpen'));
+    $this->CreateParameter('filter_transparent','',$this->Lang('param_filter_transparent'));
+    $this->CreateParameter('filter_untransparent','',$this->Lang('param_filter_untransparent'));
     $this->CreateParameter('filter_watermark','',$this->Lang('param_filter_watermark'));
   }
 
@@ -227,11 +229,16 @@ class CGSmartImage extends CGExtensions
   public function clear_cached_files()
   {
     $config = cmsms()->GetConfig();
-	$cache_path = $this->GetPreference('cache_path', cms_join_path('uploads', '_'.$this->GetName()));
-	$dir = cms_join_path($config['root_path'], $cache_path);
+    $cache_path = $this->GetPreference('cache_path', cms_join_path('uploads', '_'.$this->GetName()));
+    $dir = cms_join_path($config['root_path'], $cache_path);
+    
+    $p1 = realpath($dir);
+    $p2 = realpath($config['root_path']);
+    if( $p1 == $p2 || !startswith($p1,$p2) ) throw new Exception($this->Lang('error_cachepath_invalid'));
+
     $age_days = (int)$this->GetPreference('cache_age');
     if( $age_days <= 0 ) throw new Exception($this->Lang('error_invalid_age'));
-	  
+
     $thedate = time() - $age_days * 24 * 60 * 60;
     $n_removed = 0;
     if( $dh = opendir($dir) ) {
