@@ -101,8 +101,10 @@ $lang['param_filter_resize'] = 'type,number[,number[,upscale]] - Perform a resiz
 </ul>';
 $lang['param_filter_resizetofit'] = '(width,height[,color[,alpha]]) - Perform a resize on the image specified. This attempts to rescale the image to the destination size while reatining aspect ratio, the image is centered in the box specified (either horizontally or vertically depending upon aspect ratio and the destination size, and the image is surrounded by the supplied color.  Colors can be specified by name (see the X11 color names), or by #nnnnnn hexadecimal format, or as rgb values separated by a : i.e:  filter_croptofit=600,400,#ff0000.  The special color value &quot;transparent&quot; can be specified to force the background to be transparent (for image types that support it).   An alpha value may be specified between 0 and 127 to specify different degrees of translucency for the background.   At no time will this plugin perform any upscaling.';
 $lang['param_filter_rotate'] = '(angle) Specify the integer angle (counter clockwise) to rotate the image, The image is rotated about its center.';
-$lang['param_filter_roundedcorners'] = '(radius) Specify an integer radius (in pixels) for rounding the corners.';
+$lang['param_filter_roundedcorners'] = '(radius[,color]) Specify an integer radius (in pixels) for rounding the corners.  Optionally specify a color for the rounded corners.  The special value if &quot;transparent&quot; for the color will force the image to be converted to a png and a transparent color used.';
 $lang['param_filter_sharpen'] = '(integer) Specify an adjustment (between -10 and 10) to the sharpen filter.  Lower values will lighten the sharpening effect.  Higher values increase it.  Note: sharpening may have adverse effects on some images, and should usually be specified as the last filter, unless the filter may add borders tothe image.';
+$lang['param_filter_transparent'] = '(color[,alpha]) Converts a jpeg image to transparent PNG by converting all of the pixels of the specified color to the transparent color.  Optionally, an alpha value between 0 and 127 can be specified to indicate some alpha level blending';
+$lang['param_filter_untransparent'] = '(color[,percent]) Converts a transparent png image to a jpeg image by copying a transparent/alpha blended png overtop of an image of the appropriate color.';
 $lang['param_filter_watermark'] = '(anything), Specify that the watermark (as specified in the CGExtensions admin panel) should be applied to the image';
 $lang['param_height'] = 'Used when creating an img tag, specify the value for the height attribute.  Note, if this is not specified a value will be automatically calculated for this attribute so that most generated img tags will validate.  You can override this auto calculation with the &quot;noauto&quot; parameter.  This parameter will also be used in conjunction with the &quot;width&quot; parameter to perform a final resizing or croptofit filter (unless the &quot;noautoscale&quot; parameter is also supplied)';
 $lang['param_id'] = 'Used when creating an img tag, allows specifying an id attribute to include on the tag.  i.e: id="sometag"';
