@@ -86,7 +86,7 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
     }
 
     // quick optimization (nothing to do)
-    if( $this->_dest_w == $src['width'] && $this->_dest_h == $src['height'] ) return $src;
+    // if( $this->_dest_w == $src['width'] && $this->_dest_h == $src['height'] ) return $src;
 
     //
     // note:  this code developed by using the following page as a reference
